@@ -322,7 +322,8 @@ function afficheListe($tListe) {
 	if (is_array($tListe)) foreach ($tListe as $_lig) {
 		if (trim($_lig)!="") $tL[]=trim($_lig);
 	}
-	if ($tL[0]=="") {
+	if (empty($tL)) $tL = [];
+	if (count($tL)== 0) {
 		return "Toutes les stations vont recevoir l'ordre de s'arrêter";
 	} else {
 		return implode(", ", $tL);
@@ -332,8 +333,9 @@ function afficheListe($tListe) {
 //lecture du fichier copie_machines.db pour menu déroulant liste noms stations
 function listeStations($fic,$stationselect) {
 	if (is_array($stationselect)) foreach ($stationselect as $_lig) {
-		if (trim($_lig)!="") $tL[]=trim($_lig);
+                if (trim($_lig)!="") $tL[]=trim($_lig);
 	}
+        if (empty($tL)) $tL = [];
 
 	//si le fichier copie_machine.db n'existe pas ou qu'il est vide, on sort...
 	if (!file_exists($fic) || filesize($fic) == 0) {
@@ -368,7 +370,11 @@ function listeStations($fic,$stationselect) {
 			else if (trim($tabligne[1])=="") { //pb adresse IP
 				$noms[] = $nomsPb[] = $tabligne[0].'(adresse IP inconnue)';
 			}
-			else $noms[] = $tabligne[0];
+			else {
+				$noms[] = $tabligne[0];
+				$nomsPb = [];
+		    }
+
 		}
 		//$noms[] = $tabligne[0];
 
